@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2006 Google Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -32,21 +32,17 @@ class JndiProvider<T> implements Provider<T> {
     this.type = type;
   }
 
+  @Override
   public T get() {
     try {
       return type.cast(context.lookup(name));
-    }
-    catch (NamingException e) {
+    } catch (NamingException e) {
       throw new RuntimeException(e);
     }
   }
 
-  /**
-   * Creates a JNDI provider for the given
-   * type and name.
-   */
-  static <T> Provider<T> fromJndi(
-      Class<T> type, String name) {
+  /** Creates a JNDI provider for the given type and name. */
+  static <T> Provider<T> fromJndi(Class<T> type, String name) {
     return new JndiProvider<T>(type, name);
   }
 }
